@@ -1,5 +1,5 @@
-name = "switchbee"
-
 from .const import SWITCHBEE_BRAND
 
-__all__ = ["api", "device", "central_unit"]
+name = "switchbee"
+
+__all__ = ["api", "device", "central_unit", "wsrpc_api"]
